==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SectionHeaderCellInfoDescription } from "./SectionHeaderCellInfoDescription";
/**
 * @hidden
 */
export let SectionHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (SectionHeaderCellInfoDescriptionMetadata.a == null) {
                SectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionHeaderCellInfoDescriptionMetadata.c(SectionHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.j(SectionHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(SectionHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("ResolvedText", "String");
            a.item("ResolvedSummaryText", "String");
            a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
            a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
        }
        static d(a) {
            SectionHeaderCellInfoDescriptionMetadata.b(a);
            a.aa("SectionHeaderCellInfo", () => new SectionHeaderCellInfoDescription());
            a.z("SectionHeaderCellInfo", SectionHeaderCellInfoDescriptionMetadata.a);
        }
    }
    SectionHeaderCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(SectionHeaderCellInfoDescriptionMetadata, 'SectionHeaderCellInfoDescriptionMetadata');
    SectionHeaderCellInfoDescriptionMetadata.a = null;
    return SectionHeaderCellInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SectionHeaderCellInfoDescription } from "./SectionHeaderCellInfoDescription";
/**
 * @hidden
 */
export let SectionHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (SectionHeaderCellInfoDescriptionMetadata.a == null) {
                SectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionHeaderCellInfoDescriptionMetadata.c(SectionHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.k(SectionHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(SectionHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("ResolvedText", "String");
            a.item("ResolvedSummaryText", "String");
            a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
            a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
        }
        static d(a) {
            SectionHeaderCellInfoDescriptionMetadata.b(a);
            a.ac("SectionHeaderCellInfo", () => new SectionHeaderCellInfoDescription());
            a.ab("SectionHeaderCellInfo", SectionHeaderCellInfoDescriptionMetadata.a);
        }
    }
    SectionHeaderCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(SectionHeaderCellInfoDescriptionMetadata, 'SectionHeaderCellInfoDescriptionMetadata');
    SectionHeaderCellInfoDescriptionMetadata.a = null;
    return SectionHeaderCellInfoDescriptionMetadata;
})();
